import { NFTCategory, Rarity } from '@dcl/schemas';
export declare enum NotificationActiveTab {
    NEWEST = "newest",
    READ = "read"
}
export declare type NotificationLocale = 'en' | 'es' | 'zh';
export declare type RawDecentralandNotification<T extends DecentralandNotificationType, M> = {
    id: string;
    type: T;
    address: string;
    timestamp: number;
    read: boolean;
    created_at: string;
    updated_at: string;
    metadata: M;
};
export declare enum DecentralandNotificationType {
    ITEM_SOLD = "item_sold",
    ROYALTIES_EARNED = "royalties_earned",
    BID_ACCEPTED = "bid_accepted",
    BID_RECEIVED = "bid_received",
    GOVERNANCE_ANNOUNCEMENT = "governance_announcement",
    GOVERNANCE_PROPOSAL_ENACTED = "governance_proposal_enacted",
    GOVERNANCE_COAUTHOR_REQUESTED = "governance_coauthor_requested",
    GOVERNANCE_AUTHORED_PROPOSAL_FINISHED = "governance_authored_proposal_finished",
    GOVERNANCE_VOTING_ENDED_VOTER = "governance_voting_ended_voter",
    GOVERNANCE_NEW_COMMENT_ON_PROPOSAL = "governance_new_comment_on_proposal",
    GOVERNANCE_NEW_COMMENT_ON_PROJECT_UPDATE = "governance_new_comment_on_project_update",
    WORLDS_MISSING_RESOURCES = "worlds_missing_resources",
    WORLDS_ACCESS_RESTRICTED = "worlds_access_restricted",
    WORLDS_ACCESS_RESTORED = "worlds_access_restored",
    LAND_RENTED = "rental_started",
    LAND_RENTAL_ENDED = "rental_ended",
    REWARD_ASSIGNED = "rewards_assignment",
    EVENTS_STARTS_SOON = "events_starts_soon",
    EVENTS_STARTED = "events_started"
}
declare type CommonNFTNotificationMetadata = {
    link: string;
    image: string;
    rarity: Rarity;
    nftName: string;
    network: 'ethereum' | 'polygon';
    category: NFTCategory;
};
declare type ItemSoldMetadata = CommonNFTNotificationMetadata & {
    seller: string;
};
declare type RoyalitesEarnedMetadata = CommonNFTNotificationMetadata & {
    royaltiesCollector: string;
    royaltiesCut: string;
};
declare type BidAcceptedMetadata = CommonNFTNotificationMetadata & {
    price: string;
};
declare type BidReceivedMetadata = CommonNFTNotificationMetadata & {
    price: string;
};
export declare type ItemSoldNotification = RawDecentralandNotification<DecentralandNotificationType.ITEM_SOLD, ItemSoldMetadata>;
export declare type RoyalitesEarnedNotification = RawDecentralandNotification<DecentralandNotificationType.ROYALTIES_EARNED, RoyalitesEarnedMetadata>;
export declare type BidAcceptedNotification = RawDecentralandNotification<DecentralandNotificationType.BID_ACCEPTED, BidAcceptedMetadata>;
export declare type BidReceivedNotification = RawDecentralandNotification<DecentralandNotificationType.BID_RECEIVED, BidReceivedMetadata>;
declare type MarketplaceNotifications = ItemSoldNotification | RoyalitesEarnedNotification | BidAcceptedNotification | BidReceivedNotification;
declare type CommonGovernanceNotificationMetadata = {
    proposalId: string;
    proposalTitle: string;
    title: string;
    description: string;
    link: string;
};
export declare type GovernanceAnnouncementNotification = RawDecentralandNotification<DecentralandNotificationType.GOVERNANCE_ANNOUNCEMENT, Omit<CommonGovernanceNotificationMetadata, 'proposalId' | 'proposalTitle'>>;
export declare type GovernanceProposalEnactedNotification = RawDecentralandNotification<DecentralandNotificationType.GOVERNANCE_PROPOSAL_ENACTED, CommonGovernanceNotificationMetadata>;
export declare type GovernanceCoauthorRequestedNotification = RawDecentralandNotification<DecentralandNotificationType.GOVERNANCE_COAUTHOR_REQUESTED, CommonGovernanceNotificationMetadata>;
export declare type GovernanceAuthoredProposalFinishedNotification = RawDecentralandNotification<DecentralandNotificationType.GOVERNANCE_AUTHORED_PROPOSAL_FINISHED, CommonGovernanceNotificationMetadata>;
export declare type GovernanceVotingEndedVoterNotification = RawDecentralandNotification<DecentralandNotificationType.GOVERNANCE_VOTING_ENDED_VOTER, CommonGovernanceNotificationMetadata>;
export declare type GovernanceNewCommentOnProposalNotification = RawDecentralandNotification<DecentralandNotificationType.GOVERNANCE_NEW_COMMENT_ON_PROPOSAL, CommonGovernanceNotificationMetadata>;
export declare type GovernanceNewCommentOnProjectUpdateNotification = RawDecentralandNotification<DecentralandNotificationType.GOVERNANCE_NEW_COMMENT_ON_PROJECT_UPDATE, CommonGovernanceNotificationMetadata>;
declare type GovernanceNotifications = GovernanceAnnouncementNotification | GovernanceProposalEnactedNotification | GovernanceCoauthorRequestedNotification | GovernanceAuthoredProposalFinishedNotification | GovernanceVotingEndedVoterNotification | GovernanceNewCommentOnProposalNotification | GovernanceNewCommentOnProjectUpdateNotification;
declare type CommonWolrdsNotificationMetadata = {
    title: string;
    description: string;
    url: string;
};
declare type WorldsNotificationMetadataWithWhen = CommonWolrdsNotificationMetadata & {
    when: number;
};
export declare type WorldsMissingResourcesNotification = RawDecentralandNotification<DecentralandNotificationType.WORLDS_MISSING_RESOURCES, WorldsNotificationMetadataWithWhen>;
export declare type WorldsAccessRestrictedNotification = RawDecentralandNotification<DecentralandNotificationType.WORLDS_ACCESS_RESTRICTED, WorldsNotificationMetadataWithWhen>;
export declare type WorldsAccessRestoredNotification = RawDecentralandNotification<DecentralandNotificationType.WORLDS_ACCESS_RESTORED, CommonWolrdsNotificationMetadata>;
declare type WorldsNotifications = WorldsMissingResourcesNotification | WorldsAccessRestrictedNotification | WorldsAccessRestoredNotification;
declare type LandNotificationMetadata = {
    description: string;
    link: string;
    title: string;
    contract: string;
    lessor: string;
    tenant: string;
    operator: string;
    startedAt: string;
    endedAt: string;
    tokenId: string;
    land: string;
};
export declare type LandRentedNotification = RawDecentralandNotification<DecentralandNotificationType.LAND_RENTED, LandNotificationMetadata>;
export declare type LandRentalEndedNotification = RawDecentralandNotification<DecentralandNotificationType.LAND_RENTAL_ENDED, LandNotificationMetadata>;
declare type LandNotifications = LandRentedNotification | LandRentalEndedNotification;
export declare type RewardAssignedNotification = RawDecentralandNotification<DecentralandNotificationType.REWARD_ASSIGNED, {
    tokenName: string;
    tokenImage: string;
    tokenRarity: Rarity;
}>;
declare type CommonEventsMetadata = {
    image: string;
    link: string;
    name: string;
};
export declare type EventsStartsSoonNotification = RawDecentralandNotification<DecentralandNotificationType.EVENTS_STARTS_SOON, CommonEventsMetadata & {
    startsAt: string;
    endsAt: string;
}>;
export declare type EventsStartedNotification = RawDecentralandNotification<DecentralandNotificationType.EVENTS_STARTED, CommonEventsMetadata>;
declare type EventsNotificatiosn = EventsStartsSoonNotification | EventsStartedNotification;
export declare type DCLNotification = MarketplaceNotifications | GovernanceNotifications | WorldsNotifications | LandNotifications | RewardAssignedNotification | EventsNotificatiosn;
export declare type CommonNotificationProps<N> = {
    notification: N;
    locale: NotificationLocale;
    renderProfile?: (address: string) => JSX.Element | string | null;
};
export {};
